pub struct LayoutResult {
pub size: Size,
pub child_positions: Vec<Point>,
}Expand description
Fields
size: SizeThe resolved size of the widget after applying constraints.
child_positions: Vec<Point>The position of each child relative to this widget’s origin.
child_positions[i] corresponds to child_sizes[i] passed into layout.