Module sizing

Module sizing 

Width and Height sizing enumerations for declarative widget sizing.

Enums

Height
How a widget sizes itself on the vertical axis.
Width
How a widget sizes itself on the horizontal axis.