Module wrap
rosace_
layout
0.1.0
Module wrap
Module Items
Structs
In rosace_
layout::
widgets
rosace_layout
::
widgets
Module
wrap
Wrap
— a wrapping layout that flows children into multiple rows.
Structs

Wrap
A widget that lays out children left-to-right and wraps to a new row when the available width is exhausted.